<?php
	if (!defined('ABSPATH')) {
		exit;
	}
	/**
		* The Admin Panel and related tasks are handled in this file.
	*/
	if (!class_exists('finaluser_Admin')) {
		class finaluser_Admin {
			static $pages = array();
			public function __construct() {
				add_action('admin_menu', array($this, 'admin_menu'));
				add_action('admin_print_scripts', array($this, 'load_scripts'));
				add_action('admin_print_styles', array($this, 'load_styles'));
				add_action('wp_ajax_ep_finaluser_get_settings', array($this, 'ep_finaluser_get_settings'));
				add_action('wp_ajax_ep_finaluser_get_node', array($this, 'ep_finaluser_get_node'));
				add_action('wp_ajax_ep_finaluser_save_package', array($this, 'ep_finaluser_save_package'));
				add_action('wp_ajax_ep_finaluser_update_package', array($this, 'ep_finaluser_update_package'));
				add_action('wp_ajax_ep_finaluser_update_paypal_settings', array($this, 'ep_finaluser_update_paypal_settings'));
				add_action('wp_ajax_ep_finaluser_update_stripe_settings', array($this, 'ep_finaluser_update_stripe_settings'));
				add_action('wp_ajax_ep_finaluser_create_coupon', array($this, 'ep_finaluser_create_coupon'));
				add_action('wp_ajax_ep_finaluser_update_coupon', array($this, 'ep_finaluser_update_coupon'));
				add_action('wp_ajax_ep_finaluser_update_payment_setting', array($this, 'ep_finaluser_update_payment_setting'));
				add_action('wp_ajax_ep_finaluser_update_page_setting', array($this, 'ep_finaluser_update_page_setting'));
				add_action('wp_ajax_ep_finaluser_update_email_setting', array($this, 'ep_finaluser_update_email_setting'));
				add_action('wp_ajax_ep_finaluser_update_mailchamp_setting', array($this, 'ep_finaluser_update_mailchamp_setting'));
				add_action('wp_ajax_ep_finaluser_update_package_status', array($this, 'ep_finaluser_update_package_status'));
				add_action('wp_ajax_ep_finaluser_gateway_settings_update', array($this, 'ep_finaluser_gateway_settings_update'));
				add_action('wp_ajax_ep_finaluser_update_post_setting', array($this, 'ep_finaluser_update_post_setting'));
				add_action('wp_ajax_ep_finaluser_update_protected_setting', array($this, 'ep_finaluser_update_protected_setting'));
				add_action('wp_ajax_iv_update_protected_page_setting', array($this, 'iv_update_protected_page_setting'));
				add_action('wp_ajax_ep_finaluser_update_user_settings', array($this, 'ep_finaluser_update_user_settings'));
				add_action('wp_ajax_ep_finaluser_settings_save', array($this, 'ep_finaluser_settings_save'));
				add_action('wp_ajax_ep_finaluser_update_profile_fields', array($this, 'ep_finaluser_update_profile_fields'));
				add_action('wp_ajax_ep_finaluser_update_dir_fields', array($this, 'ep_finaluser_update_dir_fields'));
				add_action('wp_ajax_iv_update_dir_setting', array($this, 'iv_update_dir_setting'));
				add_action( 'init', array($this, 'ep_finaluser_payment_post_type') );
				add_filter( 'manage_edit-iv_payment_columns', array($this, 'set_custom_edit_iv_payment_columns')  );
				add_action( 'manage_iv_payment_posts_custom_column' ,  array($this, 'custom_iv_payment_column')  , 10, 2 );
				$this->action_hook();
				wp_admin_notifications::load();
			}
			// Hook into the 'init' action
			public function ep_finaluser_payment_post_type() {
				$args = array(
				'description' => 'ep_finaluser Payment Post Type',
				'show_ui' => true,
				'exclude_from_search' => true,
				'labels' => array(
				'name'=> 'Payment History',
				'singular_name' => 'iv_payment',
				'edit' => 'Edit Payment History',
				'edit_item' => 'Edit Payment History',
				'view' => 'View Payment History',
				'view_item' => 'View Payment History',
				'search_items' => 'Search ',
				'not_found' => 'No  Found',
				'not_found_in_trash' => 'No Found in Trash',
				),
				'public' => true,
				'publicly_queryable' => false,
				'exclude_from_search' => true,
				'show_ui' => true,
				'show_in_menu' => 'flase',
				'hiearchical' => false,
				'capability_type' => 'post',
				'hierarchical' => false,
				'rewrite' => true,
				'supports' => array('title', 'editor', 'thumbnail','excerpt','custom-fields'),
				);
				register_post_type( 'iv_payment', $args );
			}
			public function set_custom_edit_iv_payment_columns($columns) {
				
				$columns['title']='Package Name';
				$columns['User'] = 'User Name';
				$columns['Member'] = 'User ID';
				$columns['Amount'] ='Amount';
				return $columns;
			}
			public function custom_iv_payment_column( $column, $post_id ) {
				global $post;
				switch ( $column ) {
					case 'User' :
					if(isset($post->post_author) ){
						$user_info = get_userdata( $post->post_author);
						if($user_info!='' ){
							echo esc_html($user_info->user_login);
						}
					}
					break;
					case 'Member' :
					echo esc_html($post->post_author);
					break;
					case 'Amount' :
					echo esc_html($post->post_content);
					break;
				}
			}
			/**
				* Menus in the wp-admin sidebar
			*/
			public function admin_menu() {
				add_menu_page('WP ep_finaluser', 'Final User', 'manage_options', 'wp-ep_finaluser', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-package-all'] = add_submenu_page('wp-ep_finaluser', 'Package', 'Package', 'manage_options', 'wp-ep_finaluser-package-all', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-profile-form'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser Profile', 'Profile Setting', 'manage_options', 'wp-ep_finaluser-profile-form', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-coupons-form'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser Create', 'Coupons', 'manage_options', 'wp-ep_finaluser-coupons-form', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-payment-setting'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser Settings', 'Payment Gateways', 'manage_options', 'wp-ep_finaluser-payment-settings', array($this, 'menu_hook'), null);
				self::$pages['wp-iv_user-directory-admin'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser directory-admin', 'User Setting', 'manage_options', 'wp-iv_user-directory-admin', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-settings'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser Settings', 'Settings', 'manage_options', 'wp-ep_finaluser-settings', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-report'] = add_submenu_page('wp-ep_finaluser', 'WP ep_finaluser Report', 'Report', 'manage_options', 'wp-ep_finaluser-report', array($this, 'menu_hook'), null);
				self::$pages['wp-ep_finaluser-package-create'] = add_submenu_page('', 'WP ep_finaluser package', '', 'manage_options', 'wp-ep_finaluser-package-create', array($this, 'package_create_page'), null);
				self::$pages['wp-ep_finaluser-package-update'] = add_submenu_page('', 'WP ep_finaluser package', '', 'manage_options', 'wp-ep_finaluser-package-update', array($this, 'package_update_page'), null);
				self::$pages['wp-ep_finaluser-coupon-create'] = add_submenu_page('', 'WP ep_finaluser coupon', '', 'manage_options', 'wp-ep_finaluser-coupon-create', array($this, 'coupon_create_page'), null);
				self::$pages['wp-ep_finaluser-coupon-update'] = add_submenu_page('', 'WP ep_finaluser coupon', '', 'manage_options', 'wp-ep_finaluser-coupon-update', array($this, 'coupon_update_page'), null);
				self::$pages['wp-ep_finaluser-payment-paypal'] = add_submenu_page('', 'WP ep_finaluser Payment setting', '', 'manage_options', 'wp-ep_finaluser-payment-paypal', array($this, 'paypal_update_page'), null);
				self::$pages['wp-ep_finaluser-payment-authorize'] = add_submenu_page('', 'WP ep_finaluser Payment setting', '', 'manage_options', 'wp-ep_finaluser-payment-authorize', array($this, 'authorize_update_page'), null);
				self::$pages['wp-ep_finaluser-payment-stripe'] = add_submenu_page('', 'WP ep_finaluser Payment setting', '', 'manage_options', 'wp-ep_finaluser-payment-stripe', array($this, 'stripe_update_page'), null);
				self::$pages['wp-ep_finaluser-user_update'] = add_submenu_page('', 'WP ep_finaluser user_update', '', 'manage_options', 'wp-ep_finaluser-user_update', array($this, 'user_update_page'), null);
			}
			/**
				* Menu Page Router
			*/
			public function menu_hook() {
				$screen = get_current_screen();
				switch ($screen->id) {
					default:
					include ('pages/package_all.php');
					break;
					case self::$pages['wp-ep_finaluser-coupons-form']:
					include ('pages/all_coupons.php');
					break;
					case self::$pages['wp-ep_finaluser-settings']:
					include ('pages/settings.php');
					break;
					case self::$pages['wp-ep_finaluser-profile-form']:
					include ('pages/membership-profile-wizard.php');
					break;
					case self::$pages['wp-ep_finaluser-package-all']:
					include ('pages/package_all.php');
					break;
					case self::$pages['wp-ep_finaluser-payment-setting']:
					include ('pages/payment-settings.php');
					break;
					case self::$pages['wp-ep_finaluser-report']:
					include ('pages/report.php');
					break;
					case self::$pages['wp-iv_user-directory-admin']:
					include ('pages/user_directory_admin.php');
					break;
				}
			}
			public function  profile_fields_setting (){
				include ('pages/profile-fields.php');
			}
			public function coupon_create_page(){
				include ('pages/coupon_create.php');
			}
			public function coupon_update_page(){
				include ('pages/coupon_update.php');
			}
			public function package_create_page(){
				include ('pages/package_create.php');
			}
			public function package_update_page(){
				include ('pages/package_update.php');
			}
			public function authorize_update_page(){
				include ('pages/authorize_update.php');
			}
			public function paypal_update_page(){
				include ('pages/paypal_update.php');
			}
			public function stripe_update_page(){
				include ('pages/stripe_update.php');
			}
			public function user_update_page(){
				include ('pages/user_update.php');
			}
			/**
				* Page based Script Loader
			*/
			public function load_scripts() {
				$screen = get_current_screen();
				if (in_array($screen->id, array_values(self::$pages))) {
					wp_enqueue_script('jquery-ui-core');
					wp_enqueue_script('jquery-ui-datepicker');
					wp_enqueue_script('bootstrap', finaluser_URLPATH . 'admin/files/js/bootstrap.min.js');
					wp_enqueue_script('wp-ep_finaluser-script-5', finaluser_URLPATH . 'admin/files/js/epadmin.js');
					wp_localize_script('wp-ep_finaluser-script-5', 'ep_data', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ),
					'loading_image'		=> '<img src="'.finaluser_URLPATH.'admin/files/images/loader.gif">',
					'current_user_id'	=>get_current_user_id(),
					'redirecturl'	=>  finaluser_ADMINPATH.'admin.php?page=wp-ep_finaluser-coupons-form&form_submit=success',
					'login_message'		=> esc_html__('Please login to remove favorite','finaluser'),
					'redirecturlcoupon'	=>  finaluser_ADMINPATH.'admin.php?page=wp-ep_finaluser-coupons-form&form_submit=success',
					'redirecturlpackage'	=>  finaluser_ADMINPATH.'admin.php?page=wp-ep_finaluser-package-all&form_submit=success',
					'adminnonce'=> wp_create_nonce("admin"),
					'userredirect'=>finaluser_ADMINPATH.'admin.php?page=wp-iv_user-directory-admin&message=success',
					) );
				}
			}
			/**
				* Page based Style Loader
			*/
			public function load_styles() {
				$screen = get_current_screen();
				if (in_array($screen->id, array_values(self::$pages))) {
					wp_enqueue_style('jquery-ui', finaluser_URLPATH . 'admin/files/css/jquery-ui.css');					
					
					wp_enqueue_style('admin_inline_css_here', finaluser_URLPATH . 'admin/files/css/admin_inline.css');
					wp_enqueue_style('font-awesome', finaluser_URLPATH . 'admin/files/css/font-awesome/css/font-awesome.min.css');
				}
				wp_enqueue_style('wp-ep_finaluser-style-4', finaluser_URLPATH . 'admin/files/css/dashboard-admin.css');
				wp_enqueue_style('wp-ep_finaluser-style-2', finaluser_URLPATH . 'admin/files/css/iv-bootstrap.css');
			}
			/**
				* This function declares the different forms, sections and fields.
			*/
			public function settings_form() {
				register_setting('finaluser_settings', 'finaluser_settings', array($this, 'validate'));
				// General Settings
				add_settings_section('general_section', 'General Settings', 'wp_admin_forms::section_description', 'finaluser_general_section');
				add_settings_field('text_field', 'Text Field', 'wp_admin_forms::textbox', 'finaluser_general_section', 'general_section', array('id' => 'text_field', 'text' => '', 'settings' => 'finaluser_settings'));
				add_settings_field('checkbox_field', 'Checkbox Field', 'wp_admin_forms::checkbox', 'finaluser_general_section', 'general_section', array('id' => 'checkbox_field', 'text' => '', 'settings' => 'finaluser_settings'));
				add_settings_field('textarea_field', 'Textbox Field', 'wp_admin_forms::textarea', 'finaluser_general_section', 'general_section', array('id' => 'textarea_field', 'settings' => 'finaluser_settings'));
			}
			/**
				* This functions validate the submitted user input.
				* @param array $var
				* @return array
			*/
			public function validate($var) {
				return $var;
			}
			/**
				* Use this function to execute actions
			*/
			public function action_hook() {
				if (!isset($_GET['action'])) {
					return;
				}
				switch ($_GET['action']) {
				}
			}
			public function ep_finaluser_save_package() {
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:wpnonce?"));						
					exit(0);
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:user Permission?"));							
					exit(0);
				}
				parse_str($_POST['form_data'], $form_data);
				global $wpdb;
				$last_post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE post_type = 'ep_finaluser_pack' ORDER BY `ID` DESC ");
				$form_number = $last_post_id + 1;
				$role_name='';
				if($form_data['package_name']==""){
					$post_name = 'Package' . $form_number;
					$role_name=$post_name;
					}else{
					$post_name = sanitize_text_field($form_data['package_name']) .'-'. $form_number;
					$role_name=sanitize_text_field($form_data['package_name']);
				}
				$post_title=sanitize_text_field($form_data['package_name']);
				$post_content= '';
				$my_post_form = array('post_title' => wp_strip_all_tags($post_title), 'post_name' => wp_strip_all_tags($post_name), 'post_content' => $post_content, 'post_status' => 'draft', 'post_author' => get_current_user_id(),);
				$newpost_id = wp_insert_post($my_post_form);
				$post_type = 'ep_finaluser_pack';
				$query = $wpdb->prepare("UPDATE {$wpdb->prefix}posts SET post_type='%s' WHERE id='%s' LIMIT 1",$post_type,$newpost_id );
				$wpdb->query($query);
				update_post_meta($newpost_id, 'package_subtitle', $form_data['package_subtile']);
				if(isset($form_data['is_it_feature'])){
					update_post_meta($newpost_id, '_is_it_feature', sanitize_text_field($form_data['is_it_feature']));
					}else{
					update_post_meta($newpost_id, '_is_it_feature', '');
				}
				update_post_meta($newpost_id, 'ep_finaluser_package_cost', sanitize_text_field($form_data['package_cost']));
				update_post_meta($newpost_id, 'ep_finaluser_package_initial_expire_interval', sanitize_text_field($form_data['package_initial_expire_interval']));
				update_post_meta($newpost_id, 'ep_finaluser_package_initial_expire_type', sanitize_text_field($form_data['package_initial_expire_type']));
				update_post_meta($newpost_id, 'ep_finaluser_display_order', sanitize_text_field($form_data['package_order']));
				update_post_meta($newpost_id, 'ep_finaluser_image_limit', sanitize_text_field($form_data['package_image_limit']));
				update_post_meta($newpost_id, 'ep_finaluser_video_limit', sanitize_text_field($form_data['package_video_limit']));
				update_post_meta($newpost_id, 'ep_finaluser_doc_limit', sanitize_text_field($form_data['package_doc_limit']));
				if(isset($form_data['package_feature'] )){
					$package_feature= $form_data['package_feature'];
					$image_icon= (isset($form_data['feature_icon']) ? $form_data['feature_icon']:'');
					$i=0;
					for($i=0;$i<20;$i++){
						if(isset($package_feature[$i])){
							if(trim($package_feature[$i])!=''){
								update_post_meta($newpost_id, 'package_feature_'.$i, $package_feature[$i]);
								if(isset($image_icon[$i])){
									update_post_meta($newpost_id, 'feature_icon_'.$i, $image_icon[$i]);
								}
							}
						}
					}
				}
				if(isset($form_data['package_recurring'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring', sanitize_text_field($form_data['package_recurring']));
					}else{
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring', '');
				}
				update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cost_initial', sanitize_text_field($form_data['package_recurring_cost_initial']));
				update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_count', sanitize_text_field($form_data['package_recurring_cycle_count']));
				update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_type', sanitize_text_field($form_data['package_recurring_cycle_type']));
				update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_limit', sanitize_text_field($form_data['package_recurring_cycle_limit']));
				if(isset($form_data['package_enable_trial_period'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', sanitize_text_field($form_data['package_enable_trial_period']));
					}else{
					update_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', 'no');
				}
				update_post_meta($newpost_id, 'ep_finaluser_package_trial_amount', sanitize_text_field($form_data['package_trial_amount']));
				update_post_meta($newpost_id, 'ep_finaluser_package_trial_period_interval', sanitize_text_field($form_data['package_trial_period_interval']));
				update_post_meta($newpost_id, 'ep_finaluser_package_recurring_trial_type', sanitize_text_field($form_data['package_recurring_trial_type']));
				if(isset($form_data['Woocommerce_product'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_woocommerce_product', sanitize_text_field($form_data['Woocommerce_product']));
				}
				global $wp_roles;
				$contributor_roles = $wp_roles->get_role('contributor');
				$role_name_new= str_replace(' ', '_', $role_name);
				$wp_roles->remove_role( $role_name_new );
				$role_display_name = $role_name;
				$wp_roles->add_role($role_name_new, $role_display_name, array(
				'read' => true, 
				'edit_posts' => true,
				'delete_posts' => true,
				'upload_files' => true 
				));
				update_post_meta($newpost_id, 'ep_finaluser_package_user_role', $role_name_new);
				if(isset($form_data['training_program'])){
					update_post_meta($newpost_id, 'iv_training_program', sanitize_text_field($form_data['training_program']));
				}
				if(isset($form_data['package_recurring'])){
					$iv_gateway = get_option('ep_finaluser_payment_gateway');
					if($iv_gateway=='stripe'){
						include(finaluser_DIR . '/admin/files/init.php');
						$post_name2='ep_finaluser_stripe_setting';
						$row = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_name = '%s' ",$post_name2 ));
						if(isset($row->ID )){
							$stripe_id= $row->ID;
						}
						$stripe_mode=get_post_meta( $stripe_id,'ep_finaluser_stripe_mode',true);
						if($stripe_mode=='test'){
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_secret_test',true);
							}else{
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_live_secret_key',true);
						}
						$interval_count= ($form_data['package_recurring_cycle_count']=="" ? '1':$form_data['package_recurring_cycle_count']);
						$stripe_currency =get_post_meta($stripe_id, 'ep_finaluser_stripe_api_currency',true);
						\Stripe\Stripe::setApiKey($stripe_api);
						$stripe_array=array();
						$post_package_one = get_post($newpost_id);
						$p_name = $post_package_one->post_name;
						$stripe_array['id']= $p_name;
						$stripe_array['name']=$post_title;
						$stripe_array['amount']=$form_data['package_recurring_cost_initial'] * 100;
						$stripe_array['interval']=$form_data['package_recurring_cycle_type'];
						$stripe_array['interval_count']=$interval_count;
						$stripe_array['currency']=$stripe_currency;
						$trial=get_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', true);
						if($trial=='yes'){
							$trial_type = get_post_meta( $newpost_id,'ep_finaluser_package_recurring_trial_type',true);
							$trial_cycle_count =get_post_meta($newpost_id, 'ep_finaluser_package_trial_period_interval', true);
							switch ($trial_type) {
								case 'year':
								$periodNum =  365 * 1;
								break;
								case 'month':
								$periodNum =  30 * $trial_cycle_count;
								break;
								case 'week':
								$periodNum = 7 * $trial_cycle_count;
								break;
								case 'day':
								$periodNum = 1 * $trial_cycle_count;
								break;
							}
							$stripe_array['trial_period_days']=$periodNum;
						}
						\Stripe\Plan::create($stripe_array);
					}
				}
				// End Stripe Plan Create*****
				echo json_encode(array('code' => 'success'));
				exit(0);
			}
			public function iv_update_dir_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:wpnonce?"));						
					exit(0);
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:user Permission?"));							
					exit(0);
				}
				parse_str($_POST['form_data'], $form_data);
				update_option('_dir_listing_sort',sanitize_text_field($form_data['dir_listing_sort']));
				update_option('_dir_specialties',sanitize_text_field($form_data['specialties']));
				update_option('_dir_color',sanitize_text_field($form_data['dir_color']));
				update_option('_dir_map_api',sanitize_text_field($form_data['dir_map_api']));
				update_option('_dir_display_status',sanitize_text_field($form_data['dir_display_status']));
				update_option('_admin_approve_status',sanitize_text_field($form_data['admin_approve_status']));
				update_option('_profile_tab_active',sanitize_text_field($form_data['profile_tab_active']));
				update_option('_profile_photo',sanitize_text_field($form_data['profile_photo']));
				update_option('_profile_service',sanitize_text_field($form_data['profile_service']));
				update_option('_profile_follow',sanitize_text_field($form_data['profile_follow']));
				update_option('_profile_map',sanitize_text_field($form_data['profile_map']));
				update_option('_profile_contact',sanitize_text_field($form_data['profile_contact']));
				update_option('_profile_report',sanitize_text_field($form_data['profile_report']));
				update_option('listing_author_link',sanitize_text_field($form_data['listing_author_link']));
				update_option('_arch_emailaddress',sanitize_text_field($form_data['user_email_address']));
				update_option('_arch_user_phone',sanitize_text_field($form_data['user_email_phone']));
				update_option('_profile_buddypress_image',sanitize_text_field($form_data['profile_buddypress_image']));
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_profile_fields(){
				
				parse_str($_POST['form_data'], $form_data);
				$opt_array= array();
				$signup_array= array();
				$require_array= array();
				$max = sizeof($form_data['meta_name']);
				for($i = 0; $i < $max;$i++)
				{
					if($form_data['meta_name'][$i]!="" AND $form_data['meta_label'][$i]!=""){
						$opt_array[$form_data['meta_name'][$i]]=$form_data['meta_label'][$i];
						$default_signup='no';
						if(isset($form_data['signup'][$i])){
							$default_signup='yes';
							$signup_array[$form_data['signup'][$i]]=$default_signup;
						}
						$default_require='no';
						if(isset($form_data['srequire'][$i])){
							$default_require='yes';
							$require_array[$form_data['srequire'][$i]]=$default_require;
						}
					}
				}
				update_option('ep_finaluser_profile_fields', $opt_array );
				update_option('ep_finaluser_signup_fields', $signup_array );
				update_option('ep_finaluser_signup_require', $require_array );
				$opt_array2= array();
				update_option('ep_finaluser_profile_menu', '' );
				if(isset($form_data['menu_title'])){
					$max = sizeof($form_data['menu_title']);
					for($i = 0; $i < $max;$i++)
					{
						if($form_data['menu_title'][$i]!="" AND $form_data['menu_link'][$i]!=""){
							$opt_array2[$form_data['menu_title'][$i]]= sanitize_text_field($form_data['menu_link'][$i]);
						}
					}
					update_option('ep_finaluser_profile_menu', $opt_array2 );
				}
				if(isset($form_data['menutop_title'])){
					update_option( '_ep_finaluser_menutop_title' ,sanitize_text_field($form_data['menutop_title']));
				}
				if(isset($form_data['menuhome'])){
					update_option( '_ep_finaluser_menuhome' ,sanitize_text_field($form_data['menuhome']));
					update_option( '_ep_finaluser_menuhome_text' ,sanitize_text_field($form_data['textmenuhome']));
					}else{
					update_option( '_ep_finaluser_menuhome' ,'no') ;
					update_option( '_ep_finaluser_menuhome_text' ,sanitize_text_field($form_data['textmenuhome']));
				}
				if(isset($form_data['listinghome'])){
					update_option( '_ep_finaluser_menu_listinghome' ,sanitize_text_field($form_data['listinghome']));
					}else{
					update_option( '_ep_finaluser_menu_listinghome' ,'no') ;
				}
				if(isset($form_data['mylevel'])){
					update_option( '_ep_finaluser_mylevel' ,$form_data['mylevel']);
					update_option( '_ep_finaluser_mylevel_text' ,sanitize_text_field($form_data['textmylevel']));
					}else{
					update_option( '_ep_finaluser_mylevel' ,'no') ;
					update_option( '_ep_finaluser_mylevel_text' ,sanitize_text_field($form_data['textmylevel']));
				}
				if(isset($form_data['menusetting'])){
					update_option( '_ep_finaluser_menusetting' ,sanitize_text_field($form_data['menusetting']));
					update_option( '_ep_finaluser_menusetting_text' ,sanitize_text_field($form_data['textmenusetting']));
					}else{
					update_option( '_ep_finaluser_menusetting' ,'no') ;
					update_option( '_ep_finaluser_menusetting_text' ,sanitize_text_field($form_data['textmenusetting']));
				}
				if(isset($form_data['menuposts'])){
					update_option( '_ep_finaluser_menumyposts' ,sanitize_text_field($form_data['menuposts']));
					update_option( '_ep_finaluser_menumyposts_text' ,sanitize_text_field($form_data['textmenuposts']));
					}else{
					update_option( '_ep_finaluser_menumyposts' ,'no') ;
					update_option( '_ep_finaluser_menumyposts_text' ,sanitize_text_field($form_data['textmenuposts']));
				}
				if(isset($form_data['menuallposts'])){
					update_option( '_ep_finaluser_menuallposts' ,sanitize_text_field($form_data['menuallposts']));
					update_option( '_ep_finaluser_menuallposts_text' ,sanitize_text_field($form_data['textmenuallposts']));
					}else{
					update_option( '_ep_finaluser_menuallposts' ,'no') ;
					update_option( '_ep_finaluser_menuallposts_text' ,sanitize_text_field($form_data['textmenuallposts']));
				}
				if(isset($form_data['menunewpost'])){
					update_option( '_ep_finaluser_menunewpost' ,sanitize_text_field($form_data['menunewpost']));
					update_option( '_ep_finaluser_menunewpost_text' ,sanitize_text_field($form_data['textmenunewpost']));
					}else{
					update_option( '_ep_finaluser_menunewpost' ,'no') ;
					update_option( '_ep_finaluser_menunewpost_text' ,sanitize_text_field($form_data['textmenunewpost']));
				}
				if(isset($form_data['setting_images'])){
					update_option( '_ep_finaluser_images' ,sanitize_text_field($form_data['setting_images']));
					update_option( '_ep_finaluser_images_text' ,sanitize_text_field($form_data['textmenuphotos']));
					}else{
					update_option( '_ep_finaluser_images' ,'no') ;
					update_option( '_ep_finaluser_images_text' ,sanitize_text_field($form_data['textmenuphotos']));
				}
				if(isset($form_data['setting_videos'])){
					update_option( '_ep_finaluser_videos' ,sanitize_text_field($form_data['setting_videos']));
					update_option( '_ep_finaluser_videos_text' ,sanitize_text_field($form_data['textmenuvideos']));
					}else{
					update_option( '_ep_finaluser_videos' ,'no') ;
					update_option( '_ep_finaluser_videos_text' ,sanitize_text_field($form_data['textmenuvideos']));
				}
				if(isset($form_data['setting_doc'])){
					update_option( '_ep_finaluser_doc' ,sanitize_text_field($form_data['setting_doc']));
					update_option( '_ep_finaluser_doc_text' ,sanitize_text_field($form_data['textmenudoc']));
					}else{
					update_option( '_ep_finaluser_doc' ,'no') ;
					update_option( '_ep_finaluser_doc_text' ,sanitize_text_field($form_data['textmenudoc']));
				}
				if(isset($form_data['setting_activity'])){
					update_option( '_ep_finaluser_activity' ,sanitize_text_field($form_data['setting_activity']));
					update_option( '_ep_finaluser_activity_text' ,sanitize_text_field($form_data['textmenuactivity']));
					}else{
					update_option( '_ep_finaluser_activity' ,'no') ;
					update_option( '_ep_finaluser_activity_text' ,sanitize_text_field($form_data['textmenuactivity']));
				}
				if(isset($form_data['setting_notification'])){
					update_option( '_ep_finaluser_notification' ,sanitize_text_field($form_data['setting_notification']));
					update_option( '_ep_finaluser_notification_text' ,sanitize_text_field($form_data['textmenunotification']));
					}else{
					update_option( '_ep_finaluser_notification' ,'no') ;
					update_option( '_ep_finaluser_notification_text' ,sanitize_text_field($form_data['textmenunotification']));
				}
				if(isset($form_data['setting_inbox'])){
					update_option( '_ep_finaluser_inbox' ,sanitize_text_field($form_data['setting_inbox']));
					update_option( '_ep_finaluser_inbox_text' ,sanitize_text_field($form_data['textmenuinbox']));
					}else{
					update_option( '_ep_finaluser_inbox' ,'no') ;
					update_option( '_ep_finaluser_inbox_text' ,sanitize_text_field($form_data['textmenuinbox']));
				}
				if(isset($form_data['setting_compose'])){
					update_option( '_ep_finaluser_compose' ,sanitize_text_field($form_data['setting_compose']));
					update_option( '_ep_finaluser_compose_text' ,sanitize_text_field($form_data['textmenucompose']));
					}else{
					update_option( '_ep_finaluser_compose' ,'no') ;
					update_option( '_ep_finaluser_compose_text' ,sanitize_text_field($form_data['textmenucompose']));
				}
				if(isset($form_data['setting_inbox2'])){
					update_option( '_ep_finaluser_inbox2' ,sanitize_text_field($form_data['setting_inbox2']));
					update_option( '_ep_finaluser_inbox2_text' ,sanitize_text_field($form_data['textmenuinbox2']));
					}else{
					update_option( '_ep_finaluser_inbox2' ,'no') ;
					update_option( '_ep_finaluser_inbox2_text' ,sanitize_text_field($form_data['textmenuinbox2']));
				}
				if(isset($form_data['setting_sent'])){
					update_option( '_ep_finaluser_sent' ,sanitize_text_field($form_data['setting_sent']));
					update_option( '_ep_finaluser_sent_text' ,sanitize_text_field($form_data['textmenusent']));
					}else{
					update_option( '_ep_finaluser_sent' ,'no') ;
					update_option( '_ep_finaluser_sent_text' ,sanitize_text_field($form_data['textmenusent']));
				}
				if(isset($form_data['setting_woocommerce'])){
					update_option( '_ep_finaluser_woocommerce' ,sanitize_text_field($form_data['setting_woocommerce']));
					update_option( '_ep_finaluser_woocommerce_text' ,sanitize_text_field($form_data['textmenuwoocommerce']));
					}else{
					update_option( '_ep_finaluser_woocommerce' ,'no') ;
					update_option( '_ep_finaluser_woocommerce_text' ,sanitize_text_field($form_data['textmenuwoocommerce']));
				}
				if(isset($form_data['setting_order'])){
					update_option( '_ep_finaluser_order' ,sanitize_text_field($form_data['setting_order']));
					update_option( '_ep_finaluser_order_text' ,sanitize_text_field($form_data['textmenuorder']));
					}else{
					update_option( '_ep_finaluser_order' ,'no') ;
					update_option( '_ep_finaluser_order_text' ,sanitize_text_field($form_data['textmenuorder']));
				}
				if(isset($form_data['setting_subscriptions'])){
					update_option( '_ep_finaluser_subscriptions' ,sanitize_text_field($form_data['setting_subscriptions']));
					update_option( '_ep_finaluser_subscriptions_text' ,sanitize_text_field($form_data['textmenusubscriptions']));
					}else{
					update_option( '_ep_finaluser_subscriptions' ,'no') ;
					update_option( '_ep_finaluser_subscriptions_text' ,sanitize_text_field($form_data['textmenusubscriptions']));
				}
				if(isset($form_data['setting_downloads'])){
					update_option( '_ep_finaluser_downloads' ,sanitize_text_field($form_data['setting_downloads']));
					update_option( '_ep_finaluser_downloads_text' ,sanitize_text_field($form_data['textmenudownloads']));
					}else{
					update_option( '_ep_finaluser_downloads' ,'no') ;
					update_option( '_ep_finaluser_downloads_text' ,sanitize_text_field($form_data['textmenudownloads']));
				}
				if(isset($form_data['setting_billing'])){
					update_option( '_ep_finaluser_billing' ,sanitize_text_field($form_data['setting_billing']));
					update_option( '_ep_finaluser_billing_text' ,sanitize_text_field($form_data['textmenubilling']));
					}else{
					update_option( '_ep_finaluser_billing' ,'no') ;
					update_option( '_ep_finaluser_billing_text' ,sanitize_text_field($form_data['textmenubilling']));
				}
				if(isset($form_data['setting_shipping'])){
					update_option( '_ep_finaluser_shipping' ,sanitize_text_field($form_data['setting_shipping']));
					update_option( '_ep_finaluser_shipping_text' ,sanitize_text_field($form_data['textmenushipping']));
					}else{
					update_option( '_ep_finaluser_shipping' ,'no') ;
					update_option( '_ep_finaluser_shipping_text' ,sanitize_text_field($form_data['textmenushipping']));
				}
				if(isset($form_data['setting_password'])){
					update_option( '_ep_finaluser_password' ,sanitize_text_field($form_data['setting_password']));
					update_option( '_ep_finaluser_password_text' ,sanitize_text_field($form_data['textmenupassword']));
					}else{
					update_option( '_ep_finaluser_password' ,'no') ;
					update_option( '_ep_finaluser_password_text' ,sanitize_text_field($form_data['textmenupassword']));
				}
				if(isset($form_data['setting_profile'])){
					update_option( '_ep_finaluser_profile' ,sanitize_text_field($form_data['setting_profile']));
					update_option( '_ep_finaluser_profile_text' ,sanitize_text_field($form_data['textmenuprofile']));
					}else{
					update_option( '_ep_finaluser_profile' ,'no') ;
					update_option( '_ep_finaluser_profile_text' ,sanitize_text_field($form_data['textmenuprofile']));
				}
				if(isset($form_data['setting_signout'])){
					update_option( '_ep_finaluser_signout' ,sanitize_text_field($form_data['setting_signout']));
					update_option( '_ep_finaluser_signout_text' ,sanitize_text_field($form_data['textmenusignout']));
					}else{
					update_option( '_ep_finaluser_signout' ,'no') ;
					update_option( '_ep_finaluser_signout_text' ,sanitize_text_field($form_data['textmenusignout']));
				}
				update_option( '_myaccount_active_tab' ,sanitize_text_field($form_data['myaccount_active_tab']));
				// remove Prblic Profile******
				update_option( '_pprofile_tab_active' ,sanitize_text_field($form_data['pp_active_tab']));
				if(isset($form_data['pvideos'])){
					update_option( '_ep_finaluser_public_pvideos' ,sanitize_text_field($form_data['pvideos']));
					update_option( '_ep_finaluser_pvideos_text' ,sanitize_text_field($form_data['textvideos']));
					}else{
					update_option( '_ep_finaluser_public_pvideos' ,'show') ;
					update_option( '_ep_finaluser_pvideos_text' ,sanitize_text_field($form_data['textvideos']));
				}
				//  2***
				if(isset($form_data['pphotos'])){
					update_option( '_ep_finaluser_public_photos' ,sanitize_text_field($form_data['pphotos']));
					update_option( '_ep_finaluser_pphotos_text' ,sanitize_text_field($form_data['textphotos']));
					}else{
					update_option( '_ep_finaluser_public_photos' ,'show') ;
					update_option( '_ep_finaluser_pphotos_text' ,sanitize_text_field($form_data['textphotos']));
				}
				//  3***
				if(isset($form_data['pprofile'])){
					update_option( '_ep_finaluser_public_pprofile' ,sanitize_text_field($form_data['pprofile']));
					update_option( '_ep_finaluser_pprofile_text' ,sanitize_text_field($form_data['textprofile']));
					}else{
					update_option( '_ep_finaluser_public_pprofile' ,'show') ;
					update_option( '_ep_finaluser_pprofile_text' ,sanitize_text_field($form_data['textprofile']));
				}
				//  4***
				if(isset($form_data['previews'])){
					update_option( '_ep_finaluser_public_previews' ,sanitize_text_field($form_data['previews']));
					update_option( '_ep_finaluser_previews_text' ,sanitize_text_field($form_data['textreviews']));
					}else{
					update_option( '_ep_finaluser_public_previews' ,'show') ;
					update_option( '_ep_finaluser_previews_text' ,sanitize_text_field($form_data['textreviews']));
				}
				//  5***
				if(isset($form_data['ppost'])){
					update_option( '_ep_finaluser_public_ppost' ,sanitize_text_field($form_data['ppost']));
					update_option( '_ep_finaluser_ppost_text' ,sanitize_text_field($form_data['textpost']));
					}else{
					update_option( '_ep_finaluser_public_ppost' ,'show') ;
					update_option( '_ep_finaluser_ppost_text' ,sanitize_text_field($form_data['textpost']));
				}
				//  6***
				if(isset($form_data['pdocs'])){
					update_option( '_ep_finaluser_public_pdocs' ,sanitize_text_field($form_data['pdocs']));
					update_option( '_ep_finaluser_pdocs_text' ,sanitize_text_field($form_data['textdocs']));
					}else{
					update_option( '_ep_finaluser_public_pdocs' ,'show') ;
					update_option( '_ep_finaluser_pdocs_text' ,sanitize_text_field($form_data['textdocs']));
				}
				//  7***
				if(isset($form_data['pfacebook'])){
					update_option( '_ep_finaluser_public_pfacebook' ,sanitize_text_field($form_data['pfacebook']));
					update_option( '_ep_finaluser_public_pfacebook_text' ,sanitize_text_field($form_data['textpfacebook']));
					}else{
					update_option( '_ep_finaluser_public_pfacebook' ,'show') ;
					update_option( '_ep_finaluser_public_pfacebook_text' ,sanitize_text_field($form_data['textpfacebook']));
				}
				$opt_array2= array();
				update_option('ep_finaluser_profile_pptab', '' );
				if(isset($form_data['tab_title'])){
					$max = sizeof($form_data['tab_title']);
					for($i = 0; $i < $max;$i++)
					{
						if($form_data['tab_title'][$i]!="" AND $form_data['tab_link'][$i]!=""){
							$opt_array2[$form_data['tab_title'][$i]]=sanitize_text_field($form_data['tab_link'][$i]);
						}
					}
					update_option('ep_finaluser_profile_pptab', $opt_array2 );
				}
				echo json_encode(array('code' => 'Update Successfully'));
				exit(0);
			}
			public function ep_finaluser_update_dir_fields(){
				parse_str($_POST['form_data'], $form_data);
				$opt_array= array();
				$max = sizeof($form_data['meta_name']);
				for($i = 0; $i < $max;$i++)
				{
					if($form_data['meta_name'][$i]!="" AND $form_data['meta_label'][$i]!=""){
						$opt_array[$form_data['meta_name'][$i]]=$form_data['meta_label'][$i];
					}
				}
				update_option('iv_listing_Specialities', $form_data['Specialities'] );
				update_option('ep_finaluser_fields', $opt_array );
				echo json_encode(array('code' => 'Update Successfully'));
				exit(0);
			}
			public function ep_finaluser_update_package(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				$post_content="";
				global $wpdb;
				$post_title=sanitize_text_field($form_data['package_name']);
				$post_id=sanitize_text_field($form_data['package_id']);
				$newpost_id=$post_id;
				$post_content='';
				$post_type = 'ep_finaluser_pack';
				$query = $wpdb->prepare("UPDATE {$wpdb->prefix}posts SET post_title='%s', post_content='%s'  WHERE id='%s' LIMIT 1",$post_title , $post_content,$post_id  );
				$wpdb->query($query);
				update_post_meta($newpost_id, 'package_subtitle', sanitize_text_field($form_data['package_subtile']));
				if(isset($form_data['is_it_feature'])){
					update_post_meta($newpost_id, '_is_it_feature', sanitize_text_field($form_data['is_it_feature']));
					}else{
					update_post_meta($newpost_id, '_is_it_feature', '');
				}
				update_post_meta($newpost_id, 'ep_finaluser_package_cost', $form_data['package_cost']);
				update_post_meta($newpost_id, 'ep_finaluser_package_initial_expire_interval', $form_data['package_initial_expire_interval']);
				update_post_meta($newpost_id, 'ep_finaluser_package_initial_expire_type', $form_data['package_initial_expire_type']);
				update_post_meta($newpost_id, 'ep_finaluser_display_order', $form_data['package_order']);
				update_post_meta($newpost_id, 'ep_finaluser_image_limit', $form_data['package_image_limit']);
				update_post_meta($newpost_id, 'ep_finaluser_video_limit', $form_data['package_video_limit']);
				update_post_meta($newpost_id, 'ep_finaluser_doc_limit', $form_data['package_doc_limit']);
				//Woocommerce_products
				if(isset($form_data['Woocommerce_product'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_woocommerce_product', $form_data['Woocommerce_product']);
				}
				// For package_feature Save
				for($i=0;$i<21;$i++){
					delete_post_meta($newpost_id, 'package_feature_'.$i);
					delete_post_meta($newpost_id, 'feature_icon_'.$i);
				}
				if(isset($form_data['package_feature'] )){
					$package_feature= $form_data['package_feature'];
					$image_icon= (isset($form_data['feature_icon']) ? $form_data['feature_icon']:'');
					$i=0;
					for($i=0;$i<20;$i++){
						if(trim($package_feature[$i])!=''){
							update_post_meta($newpost_id, 'package_feature_'.$i, $package_feature[$i]);
							if(isset($image_icon[$i])){
								update_post_meta($newpost_id, 'feature_icon_'.$i, $image_icon[$i]);
							}
						}
					}
				}
				if(isset($form_data['package_recurring'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring', $form_data['package_recurring']);
					}else{
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring', '');
				}
				if(isset($form_data['package_recurring'])){
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring', $form_data['package_recurring']);
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cost_initial', $form_data['package_recurring_cost_initial']);
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_count', $form_data['package_recurring_cycle_count']);
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_type', $form_data['package_recurring_cycle_type']);
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring_cycle_limit', $form_data['package_recurring_cycle_limit']);
					if(isset($form_data['package_enable_trial_period'])){
						update_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', $form_data['package_enable_trial_period']);
						}else{
						update_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', 'no');
					}
					update_post_meta($newpost_id, 'ep_finaluser_package_trial_amount', $form_data['package_trial_amount']);
					update_post_meta($newpost_id, 'ep_finaluser_package_trial_period_interval', $form_data['package_trial_period_interval']);
					update_post_meta($newpost_id, 'ep_finaluser_package_recurring_trial_type', $form_data['package_recurring_trial_type']);
				}
				if(isset($form_data['training_program'])){
					update_post_meta($newpost_id, 'iv_training_program', $form_data['training_program']);
				}
				// For Stripe*****
				// For Stripe Plan Edit*****
				if(isset($form_data['package_recurring'])){
					$iv_gateway = get_option('ep_finaluser_payment_gateway');
					if($iv_gateway=='stripe'){
						include(finaluser_DIR . '/admin/files/init.php');
						$post_name2='ep_finaluser_stripe_setting';
						$row = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_name = '%s' ", $post_name2 ));
						if(isset($row->ID )){
							$stripe_id= $row->ID;
						}
						$stripe_mode=get_post_meta( $stripe_id,'ep_finaluser_stripe_mode',true);
						if($stripe_mode=='test'){
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_secret_test',true);
							}else{
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_live_secret_key',true);
						}
						$interval_count= ($form_data['package_recurring_cycle_count']=="" ? '1':$form_data['package_recurring_cycle_count']);
						$stripe_currency =get_post_meta($stripe_id, 'ep_finaluser_stripe_api_currency',true);
						\Stripe\Stripe::setApiKey($stripe_api);
						$stripe_array=array();
						$post_package_one = get_post($newpost_id);
						$p_name = $post_package_one->post_name;
						$stripe_array['id']= $p_name;
						$stripe_array['name']=$post_title;
						$stripe_array['amount']=$form_data['package_recurring_cost_initial'] * 100;
						$stripe_array['interval']=$form_data['package_recurring_cycle_type'];
						$stripe_array['interval_count']=$interval_count;
						$stripe_array['currency']=$stripe_currency;
						$trial=get_post_meta($newpost_id, 'ep_finaluser_package_enable_trial_period', true);
						if($trial=='yes'){
							$trial_type = get_post_meta( $newpost_id,'ep_finaluser_package_recurring_trial_type',true);
							$trial_cycle_count =get_post_meta($newpost_id, 'ep_finaluser_package_trial_period_interval', true);
							switch ($trial_type) {
								case 'year':
								$periodNum =  365 * 1;
								break;
								case 'month':
								$periodNum =  30 * $trial_cycle_count;
								break;
								case 'week':
								$periodNum = 7 * $trial_cycle_count;
								break;
								case 'day':
								$periodNum = 1 * $trial_cycle_count;
								break;
							}
							$stripe_array['trial_period_days']=$periodNum;
						}
						try {
							$p = \Stripe\Plan::retrieve($p_name);
							$p->delete();
							} catch (Exception $e) {
						}
						\Stripe\Plan::create($stripe_array);
					}
				}
				update_post_meta($newpost_id, 'ep_finaluser_package_category_ids', $cat_ids);
				echo json_encode(array('code' => 'success'));
				exit(0);
			}
			public function ep_finaluser_update_paypal_settings() {
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				
				parse_str($_POST['form_data'], $form_data);
				$post_content="";
				global $wpdb;
				$post_name='ep_finaluser_paypal_setting';
				$row = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_name = '%s' ",$post_name ));
				
				if(!isset($row->ID )){
					$my_post_form = array('post_title' => wp_strip_all_tags($post_name), 'post_name' => wp_strip_all_tags($post_name), 'post_content' => 'Paypal Setting', 'post_status' => 'draft', 'post_author' => get_current_user_id(),);
					$newpost_id = wp_insert_post($my_post_form);
					$post_type = 'iv_payment_setting';
					$query =$wpdb->prepare( "UPDATE {$wpdb->prefix}posts SET post_type='%s' WHERE id='%s' LIMIT 1",$post_type,$newpost_id );
					$wpdb->query($query);
					}else{
					$newpost_id= $row->ID;
				}
				
				update_post_meta($newpost_id, 'ep_finaluser_paypal_mode', sanitize_text_field($form_data['paypal_mode']));
				update_post_meta($newpost_id, 'ep_finaluser_paypal_username', sanitize_text_field($form_data['paypal_username']));
				update_post_meta($newpost_id, 'ep_finaluser_paypal_api_password', sanitize_text_field($form_data['paypal_api_password']));
				update_post_meta($newpost_id, 'ep_finaluser_paypal_api_signature', sanitize_text_field($form_data['paypal_api_signature']));
				update_post_meta($newpost_id, 'ep_finaluser_paypal_api_currency', sanitize_text_field($form_data['paypal_api_currency']));
				update_option('_ep_finaluser_api_currency', sanitize_text_field($form_data['paypal_api_currency'] ));
				
				echo json_encode(array('code' => 'success'));
				exit(0);
			}
			public function ep_finaluser_update_stripe_settings() {			
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				$post_content="";
				global $wpdb;
				$post_name='ep_finaluser_stripe_setting';
				$row = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_name = '%s' ",$post_name ));
				if(!isset($row->ID)){
					$my_post_form = array('post_title' => wp_strip_all_tags($post_name), 'post_name' => wp_strip_all_tags($post_name), 'post_content' => 'stripe Setting', 'post_status' => 'draft', 'post_author' => get_current_user_id(),);
					$newpost_id = wp_insert_post($my_post_form);
					$post_type = 'iv_payment_setting';
					$query = $wpdb->prepare("UPDATE {$wpdb->prefix}posts SET post_type='%s' WHERE id='%s' LIMIT 1",$post_type ,  $newpost_id );
					$wpdb->query($query);
					}else{
					$newpost_id= $row->ID;
				}
				update_post_meta($newpost_id, 'ep_finaluser_stripe_mode', sanitize_text_field($form_data['stripe_mode']));
				update_post_meta($newpost_id, 'ep_finaluser_stripe_live_secret_key', sanitize_text_field($form_data['secret_key']));
				update_post_meta($newpost_id, 'ep_finaluser_stripe_live_publishable_key', sanitize_text_field($form_data['publishable_key']));
				update_post_meta($newpost_id, 'ep_finaluser_stripe_secret_test', sanitize_text_field($form_data['secret_key_test']));
				update_post_meta($newpost_id, 'ep_finaluser_stripe_publishable_test', sanitize_text_field($form_data['stripe_publishable_test']));
				update_post_meta($newpost_id, 'ep_finaluser_stripe_api_currency', sanitize_text_field($form_data['stripe_api_currency']));
				update_option('_ep_finaluser_api_currency', sanitize_text_field($form_data['stripe_api_currency'] ));
				echo json_encode(array('code' => 'success'));
				exit(0);
			}
			public function ep_finaluser_create_coupon() {
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:wpnonce?"));						
					exit(0);
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:user Permission?"));							
					exit(0);
				}
				parse_str($_POST['form_data'], $form_data);
				$post_content="";
				global $wpdb;
				$post_name=sanitize_text_field($form_data['coupon_name']);
				$coupon_data = array('post_title' => wp_strip_all_tags($post_name), 'post_name' => wp_strip_all_tags($post_name), 'post_content' => $post_name, 'post_status' => 'draft', 'post_author' => get_current_user_id(),);
				$newpost_id = wp_insert_post($coupon_data);
				$post_type = 'iv_coupon';
				$query = $wpdb->prepare("UPDATE {$wpdb->prefix}posts SET post_type='%s' WHERE id='%s' LIMIT 1", $post_type,$newpost_id );
				$wpdb->query($query);
				if($form_data['coupon_count']==""){
					$coupon_limit='99999';
					}else{
					$coupon_limit=sanitize_text_field($form_data['coupon_count']);
				}
				$pac='';
				if(isset($_POST['form_pac_ids'])){$pac=$_POST['form_pac_ids'];}
				$pck_ids =implode(",",$pac);
				update_post_meta($newpost_id, 'iv_coupon_pac_id', $pck_ids);
				update_post_meta($newpost_id, 'iv_coupon_limit',$coupon_limit);
				update_post_meta($newpost_id, 'iv_coupon_start_date', sanitize_text_field($form_data['start_date']));
				update_post_meta($newpost_id, 'iv_coupon_end_date', sanitize_text_field($form_data['end_date']));
				update_post_meta($newpost_id, 'iv_coupon_amount', sanitize_text_field($form_data['coupon_amount']));
				update_post_meta($newpost_id, 'iv_coupon_type', sanitize_text_field($form_data['coupon_type']));
				echo json_encode(array('code' => 'success'));
				exit(0);
			}
			public function ep_finaluser_update_coupon() {
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:wpnonce?"));						
					exit(0);
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					echo json_encode(array("msg"=>"Are you cheating:user Permission?"));							
					exit(0);
				}
				parse_str($_POST['form_data'], $form_data);
				$post_content="";
				global $wpdb;
				$post_title=$form_data['coupon_name'];
				$post_id=sanitize_text_field($form_data['coupon_id']);
				$newpost_id=$post_id;
				$post_type = 'ep_finaluser_pack';
				$query =$wpdb->prepare( "UPDATE {$wpdb->prefix}posts SET post_title='%s' WHERE id='%s' LIMIT 1", $post_title,$post_id);
				$wpdb->query($query);
				$pck_ids =implode(",",$_POST['form_pac_ids']);
				update_post_meta($newpost_id, 'iv_coupon_pac_id', $pck_ids);
				update_post_meta($newpost_id, 'iv_coupon_limit', sanitize_text_field($form_data['coupon_count']));
				update_post_meta($newpost_id, 'iv_coupon_start_date', sanitize_text_field($form_data['start_date']));
				update_post_meta($newpost_id, 'iv_coupon_end_date', sanitize_text_field($form_data['end_date']));
				update_post_meta($newpost_id, 'iv_coupon_amount', sanitize_text_field($form_data['coupon_amount']));
				update_post_meta($newpost_id, 'iv_coupon_type', sanitize_text_field($form_data['coupon_type']));
				echo json_encode(array('code' => 'success'));
				exit(0);
			}			
			public function  ep_finaluser_update_payment_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				$iv_terms='no';
				if(isset($form_data['iv_terms'])){
					$iv_terms=sanitize_text_field($form_data['iv_terms']);
				}
				$terms_detail=sanitize_textarea_field($form_data['terms_detail']);
				$iv_coupon='';
				if(isset($form_data['iv_coupon'])){
					$iv_coupon=sanitize_text_field($form_data['iv_coupon']);
				}
				update_option('ep_finaluser_payment_terms_text', $terms_detail );
				update_option('ep_finaluser_payment_terms', $iv_terms );
				update_option('_ep_finaluser_payment_coupon', $iv_coupon );
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function iv_update_protected_page_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				update_option('_iv_membership_redirect_page',$form_data);
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_protected_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				if(isset($form_data['active_visibility'])){
					$active_visibility=sanitize_text_field($form_data['active_visibility']);
					}else{
					$active_visibility='no';
				}				
				update_option('_iv_visibility_serialize_role', $form_data);
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_post_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				if(isset($form_data['client_post_type'])){
					$post_type=sanitize_text_field($form_data['client_post_type']);
					}else{
					$post_type='post';
				}
				update_option('_ep_finaluser_profile_post', $post_type );
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function  ep_finaluser_update_page_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				$iv_terms='no';
				if(isset($form_data['iv_terms'])){
					$iv_terms=$form_data['iv_terms'];
				}
				$pricing_page=sanitize_text_field($form_data['pricing_page']);
				$signup_page=sanitize_text_field($form_data['signup_page']);
				$profile_page=sanitize_text_field($form_data['profile_page']);
				$profile_public=sanitize_text_field($form_data['profile_public']);
				$thank_you=sanitize_text_field($form_data['thank_you_page']);
				$login=sanitize_text_field($form_data['login_page']);
				$directory_page=$form_data['directory_page'];
				update_option('_ep_finaluser_price_table', $pricing_page);
				update_option('_ep_finaluser_registration', $signup_page);
				update_option('_ep_finaluser_profile_page', $profile_page);
				update_option('_ep_finaluser_profile_public_page',$profile_public);
				update_option('_ep_finaluser_thank_you_page',$thank_you);
				update_option('_ep_finaluser_login_page',$login);
				update_option('_ep_finaluser_user_dir_page',$directory_page);
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_email_setting(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				$signup_form_id=$form_data['signup_form_id'];
				update_option( 'ep_finaluser_signup_email_subject',sanitize_text_field($form_data['ep_finaluser_signup_email_subject']));
				update_option( 'ep_finaluser_signup_email',$form_data['signup_email_template']);
				update_option( 'ep_finaluser_forget_email_subject',sanitize_text_field($form_data['forget_email_subject']));
				update_option( 'ep_finaluser_forget_email',$form_data['forget_email_template']);
				update_option('admin_email_ep_finaluser', $form_data['ep_finaluser_admin_email']);
				update_option('ep_finaluser_order_client_email_sub', sanitize_text_field($form_data['ep_finaluser_order_email_subject']));
				update_option('ep_finaluser_order_client_email', $form_data['order_client_email_template']);
				update_option('ep_finaluser_order_admin_email_sub', sanitize_text_field($form_data['ep_finaluser_order_admin_email_subject']));
				update_option('ep_finaluser_order_admin_email', $form_data['order_admin_email_template']);
				update_option( 'ep_finaluser_reminder_email_subject',sanitize_text_field($form_data['ep_finaluser_reminder_email_subject']));
				update_option( 'ep_finaluser_reminder_email',$form_data['reminder_email_template']);
				update_option('ep_finaluser_reminder_day', sanitize_text_field($form_data['ep_finaluser_reminder_day']));
				update_option( 'ep_finaluser_contact_email_subject',sanitize_text_field($form_data['contact_email_subject']));
				update_option( 'ep_finaluser_contact_email',$form_data['message_email_template']);
				$bcc_message=(isset($form_data['bcc_message'])? $form_data['bcc_message']:'' );
				update_option( '_ep_finaluser_bcc_message',$bcc_message);
				update_option( 'ep_finaluser_refund_email_subject',$form_data['refund_email_subject']);
				update_option( 'ep_finaluser_refund_email',$form_data['ep_finaluser_refund_email']);
				$refund_message_link=(isset($form_data['refund_message_link'])? $form_data['refund_message_link']:'' );
				update_option( '_ep_finaluser_refund_message_link',$refund_message_link);
				update_option( 'ep_finaluser_deal_email_subject',sanitize_text_field($form_data['deal_email_subject']));
				update_option( 'ep_finaluser_deal_email',$form_data['ep_finaluser_deal_email']);
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_mailchamp_setting (){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				parse_str($_POST['form_data'], $form_data);
				update_option('ep_finaluser_mailchimp_api_key', sanitize_text_field($form_data['ep_finaluser_mailchimp_api_key']));
				update_option('ep_finaluser_mailchimp_confirmation', sanitize_text_field($form_data['ep_finaluser_mailchimp_confirmation']));
				if(isset($form_data['ep_finaluser_mailchimp_list'])){
					update_option('ep_finaluser_mailchimp_list', sanitize_text_field($form_data['ep_finaluser_mailchimp_list']));
				}
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_update_package_status (){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				global $wpdb;
				$package_id_update=trim($_POST['status_id']);
				$package_current_status=trim($_POST['status_current']);
				if($package_current_status=="pending"){
					$package_st='draft';
					$pac_msg='Active';
					}else{
					$package_st='pending';
					$pac_msg='Inactive';
				}
				$post_type = 'ep_finaluser_pack';
				$query = $wpdb->prepare("UPDATE {$wpdb->prefix}posts SET post_status='%s' WHERE ID='%s' LIMIT 1",$package_st,$package_id_update );
				$wpdb->query($query);
				echo json_encode(array("code" => "success","msg"=>$pac_msg,"current_st"=>$package_st));
				exit(0);
			}
			public function ep_finaluser_gateway_settings_update(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				$payment_gateway = $_POST['payment_gateway'];
				global $wpdb;
				update_option('ep_finaluser_payment_gateway', $payment_gateway);
				$iv_gateway = get_option('ep_finaluser_payment_gateway');
				if($iv_gateway=='stripe'){
					$stripe_id='';
					$post_name2='ep_finaluser_stripe_setting';
					$row2 = $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_name = '%s' ",$post_name2 ));
					if(isset($row2->ID )){
						$stripe_id= $row2->ID;
					}
					$sql="SELECT * FROM $wpdb->posts WHERE post_type = 'ep_finaluser_pack'";
					$membership_pack = $wpdb->get_results($sql);				
					if(sizeof($membership_pack)>0){
						$i=0;
						include(finaluser_DIR . '/admin/files/init.php');
						$stripe_mode=get_post_meta( $stripe_id,'ep_finaluser_stripe_mode',true);
						if($stripe_mode=='test'){
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_secret_test',true);
							}else{
							$stripe_api =get_post_meta($stripe_id, 'ep_finaluser_stripe_live_secret_key',true);
						}
						$stripe_currency =get_post_meta($stripe_id, 'ep_finaluser_stripe_api_currency',true);
						\Stripe\Stripe::setApiKey($stripe_api);
						foreach ( $membership_pack as $row )
						{		$package_recurring=get_post_meta( $row->ID,'ep_finaluser_package_recurring',true);
							if($package_recurring=='on'){
								$interval_count= get_post_meta( $row->ID,'ep_finaluser_package_recurring_cycle_count',true);
								$interval_count= ($interval_count=="" ? '1':$interval_count);
								$stripe_array=array();
								$p_name = $row->post_name;
								$stripe_array['id']= $p_name;
								$stripe_array['name']=$row->post_title;
								$stripe_array['amount']=get_post_meta( $row->ID,'ep_finaluser_package_recurring_cost_initial',true) * 100;
								$stripe_array['interval']=get_post_meta( $row->ID,'ep_finaluser_package_recurring_cycle_type',true);
								$stripe_array['interval_count']=$interval_count;
								$stripe_array['currency']=$stripe_currency;
								$trial=get_post_meta($row->ID, 'ep_finaluser_package_enable_trial_period', true);
								if($trial=='yes'){
									$trial_type = get_post_meta( $row->ID,'ep_finaluser_package_recurring_trial_type',true);
									$trial_cycle_count =get_post_meta($row->ID, 'ep_finaluser_package_trial_period_interval', true);
									switch ($trial_type) {
										case 'year':
										$periodNum =  365 * 1;
										break;
										case 'month':
										$periodNum =  30 * $trial_cycle_count;
										break;
										case 'week':
										$periodNum = 7 * $trial_cycle_count;
										break;
										case 'day':
										$periodNum = 1 * $trial_cycle_count;
										break;
									}
									$stripe_array['trial_period_days']=$periodNum;
								}
								try {
									\Stripe\Plan::retrieve($p_name);
									} catch (Exception $e) {
									if($stripe_array['amount']>0){
										\Stripe\Charge::create($stripe_array);
									}
								}
							}
						}
					}
				}
				// End Stripe Plan Create*****
				echo json_encode(array("code" => "success","msg"=>"Updated Successfully: Your current gateway is ".$payment_gateway));
				exit(0);
			}
			public function ep_finaluser_update_user_settings(){
				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'admin' ) ) {
					wp_die( 'Are you cheating:wpnonce?' );
				}
				if ( ! current_user_can( 'manage_options' ) ) {
					wp_die( 'Are you cheating:user Permission?' );
				}
				global $wpdb;
				parse_str($_POST['form_data'], $form_data);
				$user_id=sanitize_text_field($form_data['user_id']);
				if($form_data['exp_date']!=''){
					$exp_d=date('Y-m-d', strtotime($form_data['exp_date']));
					update_user_meta($user_id, 'ep_finaluser_exprie_date',$exp_d);
				}
				update_user_meta($user_id, 'ep_finaluser_payment_status', sanitize_text_field($form_data['payment_status']));
				update_user_meta($user_id, 'iv_user_content_setting', sanitize_text_field($form_data['content_setting']));
				update_user_meta($user_id, 'ep_status', sanitize_text_field($form_data['ep_status']));
				update_user_meta($user_id,'ep_finaluser_package_id',sanitize_text_field($form_data['package_sel']));
				$user = new WP_User( $user_id );
				$user->set_role($form_data['user_role']);
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function ep_finaluser_settings_save() {
				$sucess_message = $_POST['sucess_message'];
				$auto_reply = $_POST['auto_reply'];
				$fail_message = $_POST['fail_message'];
				$ep_finaluser_admin_email_subject = sanitize_text_field($_POST['ep_finaluser_admin_email_subject']);
				$ep_finaluser_auto_email_subject = sanitize_text_field($_POST['ep_finaluser_auto_email_subject']);
				update_option('ep_finaluser_success_message', $sucess_message);
				update_option('ep_finaluser_auto_reply', $auto_reply);
				update_option('ep_finaluser_fail_message', $fail_message);				
				echo json_encode(array("code" => "success","msg"=>esc_html__( 'Updated Successfully', 'finaluser' )));
				exit(0);
			}
			public function get_all_settings() {
				$all_options = wp_load_alloptions();
				$settings = array();
				$seriazlized_settings = array('ep_finaluser_selected_attributes');
				foreach ($all_options as $name => $value) {
					if (stristr($name, 'ep_finaluser_')) {
						if (in_array($name, $seriazlized_settings)) {
							$settings[$name] = unserialize($value);
							} else {
							$settings[$name] = $value;
						}
					}
				}
				return $settings;
			}
		}
	}
$finaluser_admin = new finaluser_Admin();